Module material

Module material 

Modules

assignments

Structs

FurShellParams
Material
See Material and FoliageMaterial.
MaterialFlags
MaterialParameters
Values assigned to known shader uniforms or None if not present.
MaterialRenderFlags
MaterialVariable
StateFlags
Flags controlling pipeline state for rasterizer and fragment state.
Texture
Selects an ImageTexture and Sampler.
WorkCallback

Enums

BlendMode
ColorWriteMode
CullMode
DepthFunc
MaterialTechniqueType
StencilMode
StencilValue
TextureUsage
Hints on how the texture is used. Actual usage is determined by the shader.

Traits

GetProgramHash